OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um arquivo.",
    "File is too big" : "O arquivo é muito grande",
    "The selected file is not an image." : "O arquivo selecionado não é uma imagem",
    "The selected file cannot be read." : "O arquivo selecionado não pôde ser lido",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize em php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE que foi especificada no formulário HTML",
    "The file was only partially uploaded" : "O arquivo foi carregado apenas parcialmente",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Faltando uma pasta temporária",
    "Could not write file to disk" : "Não foi possível gravar o arquivo no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP interrompeu o upload do arquivo",
    "Invalid file provided" : "Arquivo fornecido inválido",
    "No image or file provided" : "Nenhuma imagem ou arquivo fornecido",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com o administrador.",
    "Invalid image" : "Imagem inválida",
    "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
    "No crop data provided" : "Nenhum dado recortado fornecido",
    "No valid crop data provided" : "Nenhum dado recortado válido",
    "Crop is not square" : "Recorte não é quadrado",
    "State token does not match" : "O estado do token não coincide",
    "Invalid app password" : "Senha do aplicativo inválida",
    "Could not complete login" : "Não foi possível concluir o login",
    "Your login token is invalid or has expired" : "Seu token de login é inválido ou expirou",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versão da comunidade do Nextcloud não é compatível e as notificações por push são limitadas.",
    "Login" : "Entrar",
    "Password reset is disabled" : "A redefinição de senha está desabilitada",
    "Could not reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
    "Could not reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
    "%s password reset" : "%s redefinir senha",
    "Password reset" : "Redefinir a senha",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no botão abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no link abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
    "Reset your password" : "Redefinir sua senha",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "Alguns dos seus compartilhamentos por link foram removidos",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a um bug de segurança, tivemos que remover alguns dos seus compartilhamentos por link. Por favor, veja o link para mais informações.",
    "The user limit of this instance is reached." : "O limite do usuário desta instância foi atingido.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Insira sua chave de assinatura no aplicativo de suporte para aumentar o limite de usuários. Isso também garante a você todos os benefícios adicionais que o Nextcloud Enterprise oferece e é altamente recomendado para operação em empresas.",
    "Learn more ↗" : "Saiba mais ↗",
    "Preparing update" : "Preparando a atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Etapa do reparo:",
    "Repair info:" : "Informação do reparo:",
    "Repair warning:" : "Aviso do reparo:",
    "Repair error:" : "Erro do reparo:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, use a atualização de linha de comando, porque a atualização automática está desativada no config.php.",
    "Turned on maintenance mode" : "Ativar o modo de manutenção",
    "Turned off maintenance mode" : "Desativar o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
    "Updating database schema" : "Atualizando o schema do banco de dados",
    "Updated database" : "Atualizar o banco de dados",
    "Update app \"%s\" from App Store" : "Atualizar aplicativo \"%s\" da App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando se o schema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
    "Updated \"%1$s\" to %2$s" : "Atualizou \"%1$s\" para %2$s",
    "Set log level to debug" : "Definir o nível de log para debug",
    "Reset log level" : "Redefinir o nível do log",
    "Starting code integrity check" : "Inicializando a verificação da integridade do código",
    "Finished code integrity check" : "Finalizada a verificação de integridade do código",
    "%s (incompatible)" : "%s (incompatível)",
    "The following apps have been disabled: %s" : "Os seguintes aplicativos foram desativados: %s",
    "Already up to date" : "Já está atualizado",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Seu servidor web ainda não está configurado corretamente para permitir a sincronização de arquivos, porque a interface do WebDAV parece estar quebrada.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Seu servidor da web não está configurado corretamente para resolver \"{url}\". Mais informações podem ser encontradas na {linkstart}documentação ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Seu servidor da web não está configurado corretamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor da web que não foi atualizada para entregar essa pasta diretamente. Compare sua configuração com as regras de reescrita enviadas em \".htaccess\" para Apache ou aquela fornecida na documentação para Nginx em sua {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma atualização. ",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Seu servidor da web não está configurado corretamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada em nossa {linkstart}documentação ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar configurado corretamente para consultar variáveis de ambiente do sistema. O teste com getenv(\"PATH\") retorna apenas uma resposta vazia.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Verifique a {linkstart}documentação de instalação ↗{linkend} para notas de configuração de PHP e a configuração de PHP do seu servidor, especialmente ao usar php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração read-only foi ativada. Isso impede a definição de algumas configurações através da interface web. Além disso, o arquivo precisa ser gravado manualmente em cada atualização.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Você ainda não definiu ou verificou a configuração do seu servidor de e-mail. Por favor, vá para as {mailSettingsStart}Configurações básicas{mailSettingsEnd} para defini-las. Depois, use o botão \"Enviar e-mail\" abaixo do formulário para verificar suas configurações.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "O banco de dados não está rodando com o nível de isolamento de transação \"READ COMMITTED\". Isso pode causar problemas quando várias ações são executadas em paralelo.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "O módulo PHP \"fileinfo\" está faltando. É recomendado ativar este módulo para obter os melhores resultados com a detecção de tipos MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "O bloqueio de arquivo transacional está desabilitado, isso pode levar a problemas com condições de corrida. Habilite \"filelocking.enabled\" em config.php para evitar esses problemas. Consulte a {linkstart}documentação ↗{linkend} para obter mais informação.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Certifique-se de definir a opção \"overwrite.cli.url\" em seu arquivo config.php para a URL que seus usuários usam principalmente para acessar este Nextcloud. Sugestão: \"{suggestedOverwriteCliURL}\". Caso contrário, pode haver problemas com a geração de URL via cron. (É possível que o URL sugerido não seja o URL que seus usuários usam principalmente para acessar este Nextcloud. O melhor é verificar isso em qualquer caso.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Sua instalação não tem uma região de telefone padrão definida. Isso é necessário para validar números de telefone nas configurações do perfil sem um código de país. Para permitir números sem um código de país, adicione \"default_phone_region\" com o respectivo {linkstart}código ISO 3166-1 ↗{linkend} da região para o seu arquivo de configuração.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar a tarefa cron pelo CLI. Os seguintes erros técnicos surgiram:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Esta é a compilação da comunidade sem suporte do Nextcloud. Dado o tamanho desta instância, o desempenho, a confiabilidade e a escalabilidade não podem ser garantidos. As notificações push são limitadas para evitar sobrecarregar nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Enterprise em {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor não tem conexão com a Internet: vários pontos alvo não puderam ser alcançados. Isso significa que alguns dos recursos, como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros, não funcionarão. Acessar arquivos remotamente e enviar e-mails de notificação também pode não funcionar. Estabeleça uma conexão deste servidor com a Internet para desfrutar de todos os recursos. ",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nenhum cache de memória foi configurado. Para melhorar o desempenho, configure um memcache, se disponível. Mais informações podem ser encontradas na  {linkstart}documentação ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nenhuma fonte adequada para aleatoriedade encontrada pelo PHP, o que é altamente desencorajado por razões de segurança. Mais informações podem ser encontradas na  {linkstart}documentação ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Você está executando o PHP {version}. Atualize sua versão do PHP para aproveitar as vantagens de {linkstart}desempenho e atualizações de segurança fornecidas pelo Grupo PHP ↗{linkend} assim que sua distribuição oferecer suporte.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 é a última versão compatível com PHP 7.3. Nextcloud 24 requer pelo menos PHP 7.4. ",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "A configuração do cabeçalho do proxy reverso está incorreta ou você está acessando o Nextcloud de um proxy confiável. Caso contrário, este é um problema de segurança e pode permitir que um invasor falsifique seu endereço IP como visível para o Nextcloud. Mais informações podem ser encontradas na {linkstart}documentação ↗{linkend}. ",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached está configurado como cache distribuído, mas a extensão PHP incorreta \"memcache\" está instalada. \\OC\\Memcache\\Memcached suporta apenas \"memcached\" e não \"memcache\". Veja o {linkstart}memcached wiki sobre ambas as extensões ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Alguns arquivos não passaram na verificação de integridade. Mais informações sobre como resolver esse problema podem ser encontradas na  {linkstart1}documentação ↗{linkend}. ({linkstart2}Lista de arquivos inválidos…{linkend} / {linkstart3}Verificar novamente…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "O módulo PHP OPcache não está configurado corretamente. Veja a{linkstart}documentação ↗{linkend} para mais informações.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isso pode resultar em travamento de scripts, quebrando sua instalação. A ativação desta função é altamente recomendada.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Seu PHP não possui suporte à FreeType, resultando em problemas nas fotos de perfil e interface de configurações.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Falta o índice \"{indexName}\" na tabela \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Estão faltando alguns índices no banco de dados. Devido ao fato de que adicionar índices em tabelas grandes pode levar algum tempo, eles não foram adicionados automaticamente. Ao executar \"occ db:add-missing-indices\", os índices ausentes podem ser adicionados manualmente enquanto o Nextcloud continua em execução. Depois que os índices são adicionados, as consultas a essas tabelas geralmente são muito mais rápidas.",
    "Missing primary key on table \"{tableName}\"." : "Chave primária ausente na tabela \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "O banco de dados está sem algumas chaves primárias. Devido ao fato de que adicionar chaves primárias em tabelas grandes pode levar algum tempo, elas não foram adicionadas automaticamente. Ao executar \"occ db: add-missing-primary-keys\" essas chaves primárias ausentes podem ser adicionadas manualmente enquanto a instância continua em execução.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Falta a coluna opcional \"{columnName}\" na tabela \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Estão faltando algumas colunas opcionais no banco de dados. Devido ao fato de que adicionar colunas em grandes tabelas pode levar algum tempo, elas não foram adicionadas automaticamente por serem opcionais. Ao executar \"occ db: add-missing-columns\", elas podem ser adicionadas manualmente enquanto a instância continua em execução. Depois que as colunas são adicionadas, alguns recursos podem melhorar a capacidade de resposta ou a usabilidade.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Nesta instalação estão faltando alguns módulos PHP recomendados. Para melhor desempenho e compatibilidade, é altamente recomendável instalá-los.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP \"imagick\" não está habilitado, embora o aplicativo de temas esteja. Para que a geração de favicon funcione corretamente, você precisa instalar e habilitar este módulo.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Os módulos PHP \"gmp\" e/ou \"bcmath\" não estão habilitados. Se você usar a autenticação sem senha do WebAuthn, esses módulos serão necessários.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "A extensão php-imagick nesta instância não tem suporte para SVG. Para melhor compatibilidade é recomendado instalá-la.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algumas colunas no banco de dados não têm uma conversão para big int. Devido ao fato de que alterar os tipos de coluna em tabelas grandes pode levar algum tempo, eles não foram alterados automaticamente. Ao executar \"occ db:convert-filecache-bigint\", essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância estiver offline. Para mais detalhes, leia {linkstart}a página de documentação sobre este ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Atualmente, o SQLite está sendo usado como plataforma de banco de dados. Para instalações maiores, recomendamos que migre para outra.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Isso é recomendado ao usar o cliente da área de trabalho para sincronização de arquivos.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Para migrar para outro banco de dados, use a ferramenta de linha de comando: \"occ db:convert-type\" ou consulte a {linkstart}documentação ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "O limite de memória do PHP está abaixo do valor recomendado de 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Alguns diretórios de aplicativos são de propriedade de um usuário diferente do servidor da web. Esse pode ser o caso se os aplicativos tiverem sido instalados manualmente. Verifique as permissões dos seguintes diretórios de aplicativos:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL é usado como banco de dados, mas não oferece suporte a caracteres de 4 bytes. Para ser capaz de lidar com caracteres de 4 bytes (como emojis) sem problemas em nomes de arquivos ou comentários, por exemplo, é recomendado habilitar o suporte de 4 bytes no MySQL. Para mais detalhes, leia {linkstart}a página de documentação sobre isso ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Este Nextcloud usa um armazenamento de objeto baseado no S3 como armazenamento primário. Os arquivos enviados são armazenados temporariamente no servidor e portanto é recomendado ter 50 GB de espaço livre disponível no diretório temp do PHP. Verifique os logs para obter detalhes completos sobre o caminho e o espaço disponível. Para melhorar isso, altere o diretório temporário no arquivo php.ini ou disponibilize mais espaço nesse caminho.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "O diretório temporário desta instância aponta para um diretório não existente ou não gravável.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Você está acessando sua instância por meio de uma conexão segura, mas sua instância está gerando URLs inseguros. Isso provavelmente significa que você está atrás de um proxy reverso e as variáveis de configuração de substituição não estão definidas corretamente. Por favor leia {linkstart}a página de documentação sobre isso ↗{linkend}.",
    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Seu diretório de dados e arquivos provavelmente estão acessíveis na Internet. O arquivo .htaccess não está funcionando. É altamente recomendável que você configure seu servidor da web para que o diretório de dados não seja mais acessível ou mova o diretório de dados para fora da raiz do documento do servidor da web.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido para \"{expected}\". Este é um potencial risco de segurança ou privacidade e é recomendado ajustar esta configuração de acordo.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido para \"{expected}\". Alguns recursos podem não funcionar corretamente e é recomendado ajustar esta configuração de acordo.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não contém \"{expected}\". Este é um risco potencial de segurança ou privacidade, pois é recomendável ajustar essa configuração de acordo.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "O cabeçalho HTTP \"{header}\" não está definido para \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ou \"{val5}\". Isso pode vazar informações de referer. Veja {linkstart}Recomendações W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "O cabeçalho HTTP \"Strict-Transport-Security\" não está definido para pelo menos \"{seconds}\" seguntos. Para maior segurança, é recomendável habilitar o HSTS conforme descrito nas {linkstart}dicas de segurança ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Acessando o site de forma insegura via HTTP. É altamente recomendável configurar seu servidor para exigir HTTPS, conforme descrito nas {linkstart}dicas de segurança ↗{linkend}.",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá mundo!",
    "sunny" : "ensolarado",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
    "Hello {name}" : "Olá {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n arquivos","baixar %n arquivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
    "Update to {version}" : "Atualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor recarregue a página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi realizada com sucesso. Para mais informações <a href=\"{url}\">verifique nosso post no fórum</a> que abrange esta questão.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
    "Continue to {productName}" : "Continuar para {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
    "More apps" : "Mais aplicativos",
    "Currently open" : "Atualmente aberto",
    "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} notificações","{count} notificações"],
    "Log in" : "Entrar",
    "Logging in …" : "Entrando...",
    "Server side authentication failed!" : "Autenticação do servidor falhou!",
    "Please contact your administrator." : "Por favor, entre em contato com o administrador.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Tente novamente ou entre em contato com o administrador.",
    "Log in to {productName}" : "Faça login em {productName}",
    "Account name or email" : "Nome da conta ou e-mail",
    "Password" : "Senha",
    "Wrong username or password." : "Senha ou nome de usuário incorretos.",
    "User disabled" : "Usuário desativado",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
    "Username or email" : "Nome de usuário ou e-mail",
    "Your account is not setup for passwordless login." : "Sua conta não está configurada para login sem senha.",
    "Browser not supported" : "Navegador não suportado",
    "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
    "Your connection is not secure" : "Sua conexão não é segura",
    "Passwordless authentication is only available over a secure connection." : "A autenticação sem senha está disponível apenas em uma conexão segura.",
    "Reset password" : "Redefinir senha",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Uma mensagem de redefinição de senha foi enviada para o endereço de e-mail desta conta. Se você não o receber, verifique suas pastas de spam/lixo ou peça ajuda ao administrador local. ",
    "If it is not there ask your local administrator." : "Se não estiver lá, pergunte ao administrador.",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de redefinição. Por favor, contate o administrador.",
    "Password cannot be changed. Please contact your administrator." : "A senha não pôde ser alterada. Por favor contate seu administrador.",
    "Back to login" : "Voltar ao login",
    "New password" : "Nova senha",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Seus arquivos são criptografados. Não há como recuperar os dados depois que a senha for redefinida. Se não tiver certeza do que fazer, entre em contato com o administrador. Quer realmente continuar?",
    "I know what I'm doing" : "Eu sei o que estou fazendo",
    "Resetting password" : "Redefinindo a senha",
    "Recommended apps" : "Aplicativos recomendados",
    "Loading apps …" : "Carregando aplicativos...",
    "Could not fetch list of apps from the App Store." : "Não foi possível buscar a lista de aplicativos na App Store.",
    "Installing apps …" : "Instalando aplicativos...",
    "App download or installation failed" : "O download ou a instalação do aplicativo falhou",
    "Cannot install this app because it is not compatible" : "Não foi possível instalar este aplicativo pois não é compatível.",
    "Cannot install this app" : "Não foi possível instalar este aplicativo.",
    "Skip" : "Ignorar",
    "Install recommended apps" : "Instalar aplicativos recomendados",
    "Schedule work & meetings, synced with all your devices." : "Programe trabalhos e reuniões, sincronizados com seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha seus colegas e amigos em um só lugar sem vazar informações particulares.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicativo de e-mail simples e bem integrado com Arquivos, Contatos e Calendário.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, planilhas e apresentações, construídos no Collabora Online.",
    "Forgot password?" : "Esqueceu a senha?",
    "Log in with a device" : "Logar-se com um dispositivo",
    "Back" : "Voltar",
    "Login form is disabled." : "O formulário de login está desativado.",
    "Edit Profile" : "Editar Perfil ",
    "The headline and about sections will show up here" : "O título e as seções sobre serão exibidos aqui",
    "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
    "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente atualizar a página",
    "Search starts once you start typing" : "A pesquisa começa quando você começa a digitar",
    "Reset search" : "Redefinir pesquisa",
    "Start search" : "Começar a pesquisar",
    "Search for {name} only" : "Pesquisar somente por {nome}",
    "No results for {query}" : "Sem resultados para {query}",
    "Press enter to start searching" : "Pressione enter para iniciar a busca",
    "Start typing to search" : "Comece a digitar para pesquisar",
    "Loading more results …" : "Carregando mais resultados...",
    "Load more results" : "Carregar mais resultados",
    "Search" : "Pesquisar",
    "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
    "This browser is not supported" : "Este navegador não é compatível",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é suportado. Atualize para uma versão mais recente ou compatível.",
    "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
    "Supported versions" : "Versões compatíveis",
    "{name} version {version} and above" : "{name} versão {version} e superior",
    "Search {types} …" : "Pesquisar {types}…",
    "Settings" : "Configurações",
    "Could not load your contacts" : "Não foi possível carregar seus contatos",
    "Search contacts …" : "Procurar contatos...",
    "No contacts found" : "Nenhum contato encontrado",
    "Show all contacts …" : "Exibir todos os contatos...",
    "Install the Contacts app" : "Instalar o aplicativo Contatos",
    "Loading your contacts …" : "Carregando seus contatos...",
    "Looking for {term} …" : "Procurando por {term}…",
    "No" : "Não",
    "Yes" : "Sim",
    "No files in here" : "Nenhum arquivos aqui",
    "New folder" : "Nova pasta",
    "No more subfolders in here" : "Não há mais subpastas aqui",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido no nome do arquivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "{newName} already exists" : "{newName} já existe",
    "Choose" : "Escolher",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Erro carregando o seletor de modelo de arquivos: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Erro carregando o modelo de mensagem: {error}",
    "read-only" : "somente leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de arquivo","{count} arquivo conflita","{count} arquivo conflita"],
    "One file conflict" : "Conflito em um arquivo",
    "New Files" : "Novos arquivos",
    "Already existing files" : "Arquivos já existentes",
    "Which files do you want to keep?" : "Quais arquivos você quer manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se você selecionar ambas as versões, o arquivo copiado terá um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Erro carregando arquivo. Já existe o modelo",
    "Show list view" : "Mostrar visualização em lista",
    "Show grid view" : "Mostrar visualização em grade",
    "Pending" : "Pendente",
    "Copy to {folder}" : "Copiar para {folder}",
    "Move to {folder}" : "Mover para {folder}",
    "Saving …" : "Salvando...",
    "Authentication required" : "Autenticação necessária",
    "This action requires you to confirm your password" : "Essa ação requer que você confirme sua senha",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falha na autenticação, tente novamente",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Conexão perdida com o servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n segundos","Problema no carregamento da página, recarregando em %n segundos"],
    "Add to a project" : "Adicionar a um projeto",
    "Show details" : "Mostrar detalhes",
    "Hide details" : "Ocultar detalhes",
    "Rename project" : "Renomear projeto",
    "Failed to rename the project" : "Erro ao renomear projeto",
    "Failed to create a project" : "Erro ao criar um projeto",
    "Failed to add the item to the project" : "Erro ao adicionar o item ao projeto",
    "Connect items to a project to make them easier to find" : "Conecte itens a um projeto para torná-los mais fáceis de encontrar",
    "Type to search for existing projects" : "Digite para pesquisar projetos existentes",
    "New in" : "Novo em",
    "View changelog" : "Ver alterações",
    "Very weak password" : "Senha muito fraca",
    "Weak password" : "Senha fraca",
    "So-so password" : "Senha mais ou menos",
    "Good password" : "Senha boa",
    "Strong password" : "Senha forte",
    "No action available" : "Nenhuma ação disponível",
    "Error fetching contact actions" : "Erro ao obter as ações de contato",
    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
    "Restricted" : "Restrita",
    "Invisible" : "Invisível",
    "Delete" : "Excluir",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Personal" : "Pessoal",
    "Users" : "Usuários",
    "Apps" : "Aplicativos",
    "Admin" : "Administrar",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "Profile not found" : "Perfil não encontrado",
    "The profile does not exist." : "O perfil não existe. ",
    "Back to %s" : "Voltar para %s",
    "Page not found" : "Página não encontrada",
    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
    "Too many requests" : "Muitas requisições",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houve muitas solicitações de sua rede. Tente novamente mais tarde ou entre em contato com o administrador se isso for um erro.",
    "Error" : "Erro",
    "Previous" : "Anterior",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server was unable to complete your request." : "O servidor não conseguiu completar sua solicitação.",
    "If this happens again, please send the technical details below to the server administrator." : "Se isso acontecer novamente, envie os detalhes técnicos abaixo para o administrador do servidor.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do Pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Arquivo: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rastreamento",
    "Security warning" : "Alerta de segurança",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta de administrador</strong>",
    "Username" : "Nome do usuário",
    "Show password" : "Mostrar senha",
    "Toggle password visibility" : "Alternar visibilidade da senha",
    "Storage & database" : "Armazenamento & banco de dados",
    "Data folder" : "Pasta de dados",
    "Configure the database" : "Configurar o banco de dados",
    "Only %s is available." : "Somente %s está disponível.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
    "For more details check out the documentation." : "Para mais informações consulte a documentação.",
    "Database user" : "Usuário do banco de dados",
    "Database password" : "Senha do banco de dados",
    "Database name" : "Nome do banco de dados",
    "Database tablespace" : "Espaço de tabela do banco de dados",
    "Database host" : "Host do banco de dados",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique o nome do host e porta (ex., localhost:5432).",
    "Performance warning" : "Alerta de performance",
    "You chose SQLite as database." : "Você escolheu o SQLite como banco de dados.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "O SQLite deve ser usado apenas para instâncias mínimas e de desenvolvimento. Para produção, recomendamos um banco de dados diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se você usa clientes para sincronização de arquivos, o SQLite é altamente desencorajado.",
    "Install" : "Instalar",
    "Installing …" : "Instalando ...",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Veja a documentação",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que você está tentando reinstalar o Nextcloud. No entanto, o arquivo CAN_INSTALL está faltando no diretório de configuração. Crie o arquivo CAN_INSTALL na pasta de configuração para continuar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Não foi possível remover CAN_INSTALL da pasta de configuração. Remova este arquivo manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Este aplicativo requer JavaScript para sua correta operação. Por favor {linkstart}habilite o JavaScript{linkend} e recarregue a página.",
    "Skip to main content" : "Ir ao conteúdo principal",
    "Skip to navigation of app" : "Ir à navegação do aplicativo",
    "Get your own free account" : "Obtenha uma conta grátis",
    "%s's homepage" : "Página inicial de%s",
    "Contacts" : "Contatos",
    "Contacts menu" : "Menu de contatos",
    "Open settings menu" : "Abrir menu de configurações",
    "Confirm your password" : "Confirme sua senha",
    "Connect to your account" : "Conectar à sua conta",
    "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
    "App token" : "Token do aplicativo",
    "Grant access" : "Conceder acesso",
    "Alternative log in using app token" : "Login alternativo usando token de aplicativo",
    "Account access" : "Acesso à conta",
    "Currently logged in as %1$s (%2$s)." : "Atualmente logado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s.",
    "Account connected" : "Conta conectada",
    "Your client should now be connected!" : "Seu cliente deve estar conectado agora!",
    "You can close this window." : "Você pode fechar esta janela.",
    "This share is password-protected" : "Compartilhamento protegido por senha",
    "The password is wrong or expired. Please try again or request a new one." : "A senha está errada ou expirou. Tente novamente ou solicite uma nova.",
    "Please type in your email address to request a temporary password" : "Digite seu endereço de e-mail para solicitar uma senha temporária",
    "Email address" : "Endereço de e-mail",
    "Password sent!" : "Senha enviada!",
    "You are not authorized to request a password for this share" : "Você não está autorizado a solicitar uma senha para este compartilhamento",
    "Go to %s" : "Ir para %s",
    "Two-factor authentication" : "Autenticação de dois fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança aprimorada está ativada para sua conta. Escolha um segundo fator para autenticação:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar ao menos um dos métodos de autenticação de dois fatores ativados. Por favor, entre em contato com o administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "A autenticação de dois fatores foi aplicada, mas não foi configurada na sua conta. Entre em contato com o administrador para obter ajuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "A autenticação de dois fatores está aplicada, mas não foi configurada na sua conta. Por favor, continue a configurá-la.",
    "Set up two-factor authentication" : "Definir autenticação de dois fatores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "A autenticação de dois fatores está aplicada, mas não foi configurada na sua conta. Use um de seus códigos de backup para fazer login ou entre em contato com o administrador para obter ajuda.",
    "Use backup code" : "Use o código de backup",
    "Cancel login" : "Cancelar o login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "A segurança aprimorada é aplicada à sua conta. Escolha qual provedor configurar:",
    "Error while validating your second factor" : "Erro ao validar o segundo fator",
    "Access through untrusted domain" : "Acessar através de um domínio inseguro",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte seu administrador. Se você for o administrador, edite a configuração \"trusted_domains\" em config/config.php como o exemplo em config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informações de como configurar isso podem ser encontradas na %1$sdocumentação%2$s.",
    "App update required" : "Atualização de aplicativo é necessária",
    "%1$s will be updated to version %2$s" : "%1$s será atualizado para a versão %2$s",
    "The following apps will be updated:" : "Os seguintes aplicativos serão atualizados:",
    "These incompatible apps will be disabled:" : "Estes aplicativos incompatíveis serão desabilitados:",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que o banco de dados, a pasta config e a pasta de dados foram copiados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar atingir o tempo limite em instalações maiores, você pode em vez disso executar o seguinte comando a partir do diretório de instalação:",
    "Detailed logs" : "Logs detalhados",
    "Update needed" : "Atualização necessária",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Use o atualizador pela linha de comando pois você tem uma grande instalação com mais de 50 usuários",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Precisando de ajuda, leia a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar atualizando pela interfaceweb, há o risco de atingir o tempo limite e ocorrer perda de dados mas eu tenho um cópia de backup e sei como restaurar meu sistema se isso ocorrer.",
    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco",
    "Maintenance mode" : "Modo de manutenção",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
    "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Digite sua chave de assinatura para aumentar o limite de usuários. Para obter mais informações sobre o Nextcloud Enterprise, consulte nosso website.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabela %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não possui conexão com a internet: Vários pontos não puderam ser acessados. Isso significa que alguns dos recursos como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros não funcionarão. Acesso a arquivos remotos e envio de e-mails de notificação não funcionarão também. Estabeleça uma conexão deste servidor com a Internet para aproveitar todos os recursos.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 é a última versão compatível com PHP 7.2. Nextcloud 21 requer ao menos PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "A extensão PHP OPcache não está carregada. {linkstart}Para melhor desempenho, é recomendado ↗{linkado} carregá-la na instalação do PHP.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "A extensão PHP OPcache não está configurada corretamente. {linkstart}Para melhor desempenho é recomendado↗{linkend} usar as seguintes configurações no <code>php.ini</code>:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algumas colunas do banco de dados estão sem uma conversão para big int. Devido ao fato de que alterar os tipos de coluna em tabelas grandes pode levar algum tempo, elas não foram alteradas automaticamente. Executando 'occ db: convert-filecache-bigint' essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância está offline. Para obter mais detalhes, leia {linkstart} a página de documentação sobre isso ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Para migrar para outro banco de dados, use a ferramenta de linha de comando: 'occ db:convert-type', ou consulte a  {linkstart}documentação do ↗{linkend}. ",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Seu diretório de dados e arquivos provavelmente podem ser acessados pela Internet. O arquivo .htaccess não está funcionando. É altamente recomendado que você configure seu servidor web para que o diretório de dados não seja mais acessível ou mova o diretório de dados fora da raiz de documentos do servidor web.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não contém \"{expected}\". Esse é um risco potencial de segurança ou privacidade. É recomendável ajustar essa configuração de acordo.",
    "Collaboratively edit office documents." : "Edite documentos de escritório colaborativamente.",
    "Local document editing back-end used by the Collabora Online app." : "Backend de edição de documentos local usado pelo aplicativo Collabora Online.",
    "restricted" : "restrito",
    "invisible" : "Invisível",
    "File not found" : "Arquivo não encontrado",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "O documento não pôde ser encontrado no servidor. Talvez o compartilhamento tenha sido excluído ou tenha expirado.",
    "More" : "Mais",
    "More apps menu" : "Mais aplicativos",
    "Settings menu" : "Menu de configurações",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Setup two-factor authentication" : "Configurar autenticação de dois fatores",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis. ",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Este é a construção de uma comunidade sem suporte do Nextcloud. Dado o tamanho desta instância, desempenho, confiabilidade e escalabilidade não podem ser garantidos. As notificações push foram desativadas para evitar sobrecarregar nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Enterprise em nextcloud.com/enterprise. ",
    "You haven't added any info yet" : "Você ainda não adicionou nenhuma informação",
    "{user} hasn't added any info yet" : "{user} ainda não adicionou nenhuma informação"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
